import os, sys
import shutil

YUI_VERSION = '2.7.0'
YUI_DOWNLOAD_VERSION = '2.7.0b' # argh, download file version isn't actual version

from hurry.yui.depend import depend
from hurry.yui.download import download

def main():
    try:
        version = sys.argv[1]
    except IndexError:
        print "Usage: yuiprepare <YUI version> [<download version>]"
        return

    try:
        download_version = sys.argv[2]
    except IndexError:
        download_version = version

    # download YUI library into package
    package_dir = os.path.dirname(__file__)

    prepare(package_dir)

def working_entrypoint(data):
    if data['name'] != 'hurry.yui':
        return
    prepare(os.path.dirname(__file__))

def tag_entrypoint(data):
    if data['name'] != 'hurry.yui':
        return
    prepare(data['tagdir'] + '/src/hurry/yui')
    
def prepare(package_dir):
    yui_dest_path = os.path.join(package_dir, 'yui-build')

    # remove previous yui library
    shutil.rmtree(yui_dest_path, ignore_errors=True)

    def copy_yui(ex_path):
        """Copy YUI to location 'yui-build' in package."""
        yui_build_path = os.path.join(ex_path, 'yui', 'build')
        shutil.copytree(yui_build_path, yui_dest_path)

    download(YUI_DOWNLOAD_VERSION, copy_yui)

    # get dependency structure and create 'yui.py' into package
    code = depend(YUI_VERSION)
    yui_py_path = os.path.join(package_dir, 'yui.py')
    f = open(yui_py_path, 'w')
    f.write(code)
    f.close()



import urllib2
import tempfile, shutil
import os

URL_TEMPLATE = 'http://yuilibrary.com/downloads/yui2/yui_%s.zip'

def download(version, callback):
    """Download a yui of version.

    When downloaded, call callback with path to directory
    with an extracted YUI. The callback will then be able to copy
    this to the appropriate location.
    """
    download_url = URL_TEMPLATE % version
   
    f = urllib2.urlopen(download_url)
    file_data = f.read()
    f.close()

    dirpath = tempfile.mkdtemp()
    try:
        yui_path = os.path.join(dirpath, 'yui.zip')
        ex_path = os.path.join(dirpath, 'yui_ex')
        g = open(yui_path, 'wb')
        g.write(file_data)
        g.close()
        os.system('unzip -qq "%s" -d "%s"' % (yui_path, ex_path))
        callback(ex_path)
    finally:
        shutil.rmtree(dirpath, ignore_errors=True)



import sys, os
import urllib2
import simplejson

from hurry.resource import Library, ResourceInclusion, generate_code

YUILOADER_BETA_URL_TEMPLATE = ('http://yui.yahooapis.com/%s/build/yuiloader'
                               '/yuiloader-beta.js')

YUILOADER_URL_TEMPLATE = ('http://yui.yahooapis.com/%s/build/yuiloader'
                         '/yuiloader.js')

def depend(version):
    d = load_json(version)
    return convert_to_inclusions(d)

def convert_to_inclusions(d):
    yui = Library('yui', 'yui-build')
    inclusion_map = {}
    for name, value in d.items():
        name = normalize_name(name)
        inclusion_map[name] = ResourceInclusion(yui,
                                                deminize(value['path']))
                
    # fix up dependency structure
    # XXX note that this doesn't establish proper rollup backreferences
    # but this doesn't matter as we're just going to generate the
    # code that does...
    for name, value in d.items():
        name = normalize_name(name)
        inclusion = inclusion_map[name]

        for require in value.get('requires', []):
            require = normalize_name(require)
            inclusion.depends.append(inclusion_map[require])

        for supersede_name in value.get('supersedes', []):
            orig_supersede_name = supersede_name
            supersede_name = normalize_name(supersede_name)
            r = inclusion_map[supersede_name]
            # only supersede things that don't supersede themselves
            if not d[orig_supersede_name].get('supersedes'):
                inclusion.supersedes.append(r)

        for mode_name in get_modes(inclusion):
            inclusion.modes[mode_name] = mode_inclusion = convert_to_mode(
                inclusion, mode_name)

    # add the SAM skin
    sam = ResourceInclusion(yui, 'assets/skins/sam/skin.css')
    inclusion_map['sam'] = sam
    
    # now generate code
    return generate_code(**inclusion_map)
    
def normalize_name(n):
    return str(n.replace('-', '_'))

def deminize(path):
    rest, ext = os.path.splitext(path)
    if rest.endswith('-min'):
        rest = rest[:-len('-min')]
    return rest + ext

def convert_to_mode(inclusion, mode):
    rest, ext = os.path.splitext(inclusion.relpath)
    if mode == 'minified' and not inclusion.supersedes:
        result = ResourceInclusion(inclusion.library,
                                   rest + '-min' + ext)
    elif mode == 'debug' and not inclusion.supersedes:
        result = ResourceInclusion(inclusion.library,
                                   rest + '-debug' + ext)
    else:
        result = inclusion
        
    return result

def get_modes(inclusion):
    ext = inclusion.ext()
    if ext == '.css':
        return ['minified']
    elif ext == '.js':
        return ['minified', 'debug']
    else:
        return []
    
def load_json(version):
    try:
        f = urllib2.urlopen(YUILOADER_URL_TEMPLATE % version)
        data = f.read()
        f.close()
    except urllib2.HTTPError:
        f = urllib2.urlopen(YUILOADER_BETA_URL_TEMPLATE % version)
        data = f.read()
        f.close()
    s = "'moduleInfo': "
    i = data.find(s)
    i = i + len(s)
    j = data.find("'yuitest': {", i)
    j = data.find('}', j)
    j = data.find('}', j + 1)
    text = data[i:j + 1]
    json = normalize_json(text)
    return simplejson.loads(json)

def normalize_json(text):
    # proper json has doubly quoted strings
    text = text.replace("'", '"')
    result = []
    for line in text.splitlines():
        i = line.find('//')
        if i != -1:
            line = line[:i] + '\n'
        result.append(line)
    return ''.join(result)



from setuptools import setup, find_packages

import sys, os

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('README.txt')
    + '\n' +
    read('CHANGES.txt')
    + '\n' +
    'Download\n'
    '********\n'
    )


setup(
    name='hurry.yui',
    version='2.7.0.1',
    description="hurry.resource style resources for YUI.",
    long_description = long_description,
    classifiers=[],
    keywords='',
    author='Martijn Faassen',
    author_email='faassen@startifact.com',
    license='ZPL 2.1',
    packages=find_packages('src'),
    namespace_packages=['hurry'],
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'hurry.resource > 0.9',
        'simplejson',
        ],
    entry_points= {
        'console_scripts': [
            'yuiprepare = hurry.yui.prepare:main',
            ],
        'zest.releaser.prereleaser.middle': [
            'prepare = hurry.yui.prepare:working_entrypoint',
            ],
        'zest.releaser.releaser.after_checkout': [
            'prepare = hurry.yui.prepare:tag_entrypoint',
            ],
        'hurry.resource.libraries': [
            'yui = hurry.yui:yui',
            ],    
        },
    
    )



from hurry.resource import Library, ResourceInclusion

yui = Library('yui', 'yui-build')

fonts = ResourceInclusion(yui, 'fonts/fonts.css', minified='fonts/fonts-min.css')
grids = ResourceInclusion(yui, 'grids/grids.css', depends=[fonts], minified='grids/grids-min.css')
sam = ResourceInclusion(yui, 'assets/skins/sam/skin.css')
reset = ResourceInclusion(yui, 'reset/reset.css', minified='reset/reset-min.css')
reset_fonts = ResourceInclusion(yui, 'reset-fonts/reset-fonts.css', supersedes=[reset, fonts], minified='reset-fonts/reset-fonts.css')
reset_fonts_grids = ResourceInclusion(yui, 'reset-fonts-grids/reset-fonts-grids.css', supersedes=[reset, fonts, grids], minified='reset-fonts-grids/reset-fonts-grids.css')
base = ResourceInclusion(yui, 'base/base.css', minified='base/base-min.css')
yahoo = ResourceInclusion(yui, 'yahoo/yahoo.js', debug='yahoo/yahoo-debug.js', minified='yahoo/yahoo-min.js')
event = ResourceInclusion(yui, 'event/event.js', depends=[yahoo], debug='event/event-debug.js', minified='event/event-min.js')
dom = ResourceInclusion(yui, 'dom/dom.js', depends=[yahoo], debug='dom/dom-debug.js', minified='dom/dom-min.js')
imageloader = ResourceInclusion(yui, 'imageloader/imageloader.js', depends=[event, dom], debug='imageloader/imageloader-debug.js', minified='imageloader/imageloader-min.js')
containercore = ResourceInclusion(yui, 'container/container_core.js', depends=[dom, event], debug='container/container_core-debug.js', minified='container/container_core-min.js')
calendar = ResourceInclusion(yui, 'calendar/calendar.js', depends=[event, dom], debug='calendar/calendar-debug.js', minified='calendar/calendar-min.js')
profiler = ResourceInclusion(yui, 'profiler/profiler.js', depends=[yahoo], debug='profiler/profiler-debug.js', minified='profiler/profiler-min.js')
element = ResourceInclusion(yui, 'element/element.js', depends=[dom, event], debug='element/element-debug.js', minified='element/element-min.js')
paginator = ResourceInclusion(yui, 'paginator/paginator.js', depends=[element], debug='paginator/paginator-debug.js', minified='paginator/paginator-min.js')
container = ResourceInclusion(yui, 'container/container.js', depends=[dom, event], supersedes=[containercore], debug='container/container.js', minified='container/container.js')
simpleeditor = ResourceInclusion(yui, 'editor/simpleeditor.js', depends=[element], debug='editor/simpleeditor-debug.js', minified='editor/simpleeditor-min.js')
menu = ResourceInclusion(yui, 'menu/menu.js', depends=[containercore], debug='menu/menu-debug.js', minified='menu/menu-min.js')
stylesheet = ResourceInclusion(yui, 'stylesheet/stylesheet.js', depends=[yahoo], debug='stylesheet/stylesheet-debug.js', minified='stylesheet/stylesheet-min.js')
json = ResourceInclusion(yui, 'json/json.js', depends=[yahoo], debug='json/json-debug.js', minified='json/json-min.js')
datasource = ResourceInclusion(yui, 'datasource/datasource.js', depends=[event], debug='datasource/datasource-debug.js', minified='datasource/datasource-min.js')
charts = ResourceInclusion(yui, 'charts/charts.js', depends=[element, json, datasource], debug='charts/charts-debug.js', minified='charts/charts-min.js')
button = ResourceInclusion(yui, 'button/button.js', depends=[element], debug='button/button-debug.js', minified='button/button-min.js')
editor = ResourceInclusion(yui, 'editor/editor.js', depends=[menu, element, button], supersedes=[simpleeditor], debug='editor/editor.js', minified='editor/editor.js')
get = ResourceInclusion(yui, 'get/get.js', depends=[yahoo], debug='get/get-debug.js', minified='get/get-min.js')
yuiloader_dom_event = ResourceInclusion(yui, 'yuiloader-dom-event/yuiloader-dom-event.js', supersedes=[yahoo, dom, event, get], debug='yuiloader-dom-event/yuiloader-dom-event.js', minified='yuiloader-dom-event/yuiloader-dom-event.js')
animation = ResourceInclusion(yui, 'animation/animation.js', depends=[dom, event], debug='animation/animation-debug.js', minified='animation/animation-min.js')
dragdrop = ResourceInclusion(yui, 'dragdrop/dragdrop.js', depends=[dom, event], debug='dragdrop/dragdrop-debug.js', minified='dragdrop/dragdrop-min.js')
carousel = ResourceInclusion(yui, 'carousel/carousel.js', depends=[element], debug='carousel/carousel-debug.js', minified='carousel/carousel-min.js')
logger = ResourceInclusion(yui, 'logger/logger.js', depends=[event, dom], debug='logger/logger-debug.js', minified='logger/logger-min.js')
slider = ResourceInclusion(yui, 'slider/slider.js', depends=[dragdrop], debug='slider/slider-debug.js', minified='slider/slider-min.js')
colorpicker = ResourceInclusion(yui, 'colorpicker/colorpicker.js', depends=[slider, element], debug='colorpicker/colorpicker-debug.js', minified='colorpicker/colorpicker-min.js')
resize = ResourceInclusion(yui, 'resize/resize.js', depends=[dom, event, dragdrop, element], debug='resize/resize-debug.js', minified='resize/resize-min.js')
imagecropper = ResourceInclusion(yui, 'imagecropper/imagecropper.js', depends=[dom, event, dragdrop, element, resize], debug='imagecropper/imagecropper-debug.js', minified='imagecropper/imagecropper-min.js')
yuitest = ResourceInclusion(yui, 'yuitest/yuitest.js', depends=[logger], debug='yuitest/yuitest-debug.js', minified='yuitest/yuitest-min.js')
connection = ResourceInclusion(yui, 'connection/connection.js', depends=[event], debug='connection/connection-debug.js', minified='connection/connection-min.js')
utilities = ResourceInclusion(yui, 'utilities/utilities.js', supersedes=[yahoo, event, dragdrop, animation, dom, connection, element, get], debug='utilities/utilities.js', minified='utilities/utilities.js')
cookie = ResourceInclusion(yui, 'cookie/cookie.js', depends=[yahoo], debug='cookie/cookie-debug.js', minified='cookie/cookie-min.js')
uploader = ResourceInclusion(yui, 'uploader/uploader.js', depends=[element], debug='uploader/uploader-debug.js', minified='uploader/uploader-min.js')
layout = ResourceInclusion(yui, 'layout/layout.js', depends=[dom, event, element], debug='layout/layout-debug.js', minified='layout/layout-min.js')
yuiloader = ResourceInclusion(yui, 'yuiloader/yuiloader.js', supersedes=[yahoo, get], debug='yuiloader/yuiloader.js', minified='yuiloader/yuiloader.js')
profilerviewer = ResourceInclusion(yui, 'profilerviewer/profilerviewer.js', depends=[profiler, yuiloader, element], debug='profilerviewer/profilerviewer-debug.js', minified='profilerviewer/profilerviewer-min.js')
datatable = ResourceInclusion(yui, 'datatable/datatable.js', depends=[element, datasource], debug='datatable/datatable-debug.js', minified='datatable/datatable-min.js')
selector = ResourceInclusion(yui, 'selector/selector.js', depends=[yahoo, dom], debug='selector/selector-debug.js', minified='selector/selector-min.js')
tabview = ResourceInclusion(yui, 'tabview/tabview.js', depends=[element], debug='tabview/tabview-debug.js', minified='tabview/tabview-min.js')
autocomplete = ResourceInclusion(yui, 'autocomplete/autocomplete.js', depends=[dom, event, datasource], debug='autocomplete/autocomplete-debug.js', minified='autocomplete/autocomplete-min.js')
yahoo_dom_event = ResourceInclusion(yui, 'yahoo-dom-event/yahoo-dom-event.js', supersedes=[yahoo, event, dom], debug='yahoo-dom-event/yahoo-dom-event.js', minified='yahoo-dom-event/yahoo-dom-event.js')
treeview = ResourceInclusion(yui, 'treeview/treeview.js', depends=[event, dom], debug='treeview/treeview-debug.js', minified='treeview/treeview-min.js')
history = ResourceInclusion(yui, 'history/history.js', depends=[event], debug='history/history-debug.js', minified='history/history-min.js')